@@ -30,6 +30,8 @@ typedef struct aacenc_frame_t {
     uint32_t size, capacity;
 } aacenc_frame_t;
 
+int aacenc_is_explicit_bw_compatible_sbr_signaling_available();
+
 int aacenc_is_sbr_ratio_available();
 
 int aacenc_is_sbr_active(const aacenc_param_t *params);
@@ -38,6 +40,10 @@ int aacenc_is_dual_rate_sbr(const aacenc_param_t *params);
 
 void aacenc_get_lib_info(LIB_INFO *info);
 
+int aacenc_mp4asc(const aacenc_param_t *params,
+                  const uint8_t *asc, uint32_t ascsize,
+                  uint8_t *outasc, uint32_t *outsize);
+
 int aacenc_init(HANDLE_AACENCODER *encoder, const aacenc_param_t *params,
                 const pcm_sample_description_t *format,
                 AACENC_InfoStruct *info);
