@@ -39,6 +39,14 @@ typedef struct m4af_chunk_entry_t {
     uint32_t duration;
 } m4af_chunk_entry_t;
 
+typedef struct m4af_itmf_entry_t {
+    uint32_t fcc;
+    char *name;
+    uint32_t type_code;
+    char *data;
+    uint32_t data_size;
+} m4af_itmf_entry_t;
+
 typedef struct m4af_track_t {
     uint32_t codec;
     uint32_t timescale;
@@ -1374,7 +1382,6 @@ uint64_t m4af_patch_moov(m4af_ctx_t *ctx, uint32_t moov_size, uint32_t offset)
 static
 void m4af_shift_mdat_pos(m4af_ctx_t *ctx, uint32_t offset)
 {
-    unsigned i, j;
     int64_t begin, end;
     char *buf;
     
